==> trackballs_1.3.1.orig.tar.gz: trackballs-1.3.1/AUTHORS.md <==
## The people behind trackballs

    Mathias Broxvall    project founder and administrator
    Dietrich Radel      graphics, music, levels, documentation, bugs etc.
    Yannick Perret      extra coder: 
    Samuel Listopad     windows port
    Ari Pollak          Debian packaging, security & build patches

### Translators

    English Translation    Mathias Broxvall        
    Swedish Translation    Mathias Broxvall        
    Italian Translation    Francesco Guatieri      
    French Translation     Guillaume Bedot         
    Slovak Translation     Jozef Riha <jose1711@gmail.com>

### Fonts

The sans-serif truetype font used in games came from UCS Outline Fonts 
([http://www.nongnu.org/freefont/](http://www.nongnu.org/freefont/)) and is GPL'ed. 
[The link as of 2017 redirects to GNU FreeFont]

The bold italic serif truetype menu font comes from the GNU FreeFont
project ([https://www.gnu.org/software/freefont/](https://www.gnu.org/software/freefont/)) and is GPL'ed.

### Music

    tb_design.ogg aka. "Life by Design", by Dietrich Radel
    tg_genesis.ogg aka. "Genesis (In The Beginning)", by Dietrich Radel
    tb_hrluebke.ogg, by M3 (Marco Göbel <goebel29@web.de>)
    tb_plinkeplanke.ogg, by M3 (Marco Göbel <goebel29@web.de>)
    tb_schizophrenia.ogg, by Attila Boros (Attila Boros <wraith13@gmail.com>)
    tb_sorrow.ogg, by Attila Boros (Attila Boros <wraith13@gmail.com>)

### Images

Mathias Broxvall, Dietrich Radel. All GPL'ed


### Sound effects

The sound effects are taken from KDE, from Benoit Rouits and from 
Joshua Harding. They are of course all GPL'ed.

    blackDie.wav         - Benoit Rouits
    ff_death.wav         - Benoit Rouits
    levelComplete.wav    - Benoit Rouits
    start.wav            - Benoit Rouits
    die.wav              - Benoit Rouits
    flag.wav             - KDE
    sandcrash.wav        - Benoit Rouits
    time_warning.wav     - Benoit Rouits
    switch.wav           - Benoit Rouits
    badpill.wav          - Joshua Harding
    godppill.wav         - Joshua Harding
    savepoint.wav        - Joshua Harding
    timeout.wav          - Joshua Harding
    capuchmonk.wav       - Rusty Johnson     http://www.WildlifeLectures.com
    fall_death.wav       - Laurent           http://www.tplm.com
    Kill_death.wav       - Bob Bailey        http://www.a1freesoundeffects.com
    crash.wav            - Justus            http://www.sq7.org/Community/sounds
    roll_sound.wav       - Warren D.Ober     Contributor
    machine_loop.wav     - Warren D.Ober     Contributor
    click.wav            - Warren D.Ober     Contributor
    ball_sinks.wav       - Warren D.Ober     Contributor
    ball_sinks2.wav      - Warren D.Ober     Contributor


Also, for one of the sound effects I have promised to include this
notice:

       **                                     **
       **  The sample of the Capuchin Monkey  **
       **  call is provided courtesy of:      **
       **                                     **
       **        Rusty Johnson                **
       **        The Aylazon Foundation       **
       **        WildlifeLectures.com         **
       **                                     **

==> trackballs_1.3.5.orig.tar.gz: trackballs-1.3.5/AUTHORS.md <==
## The people behind trackballs

    Mathias Broxvall    project founder and administrator
    Dietrich Radel      graphics, music, levels, documentation, bugs etc.
    Yannick Perret      extra coder: 
    Samuel Listopad     windows port
    Ari Pollak          Debian packaging, security & build patches
    Manuel Stoeckl      maintaining trackballs since 2017

### Translators

    English Translation    Mathias Broxvall        
    Swedish Translation    Mathias Broxvall        
    Italian Translation    Francesco Guatieri      
    French Translation     Guillaume Bedot, Manuel Stoeckl
    Slovak Translation     Jozef Riha <jose1711@gmail.com>
    German Translation     Manuel Stoeckl

### Fonts

The sans-serif truetype font used in games came from UCS Outline Fonts 
([http://www.nongnu.org/freefont/](http://www.nongnu.org/freefont/)) and is GPL'ed. 
[The link as of 2017 redirects to GNU FreeFont]

The bold italic serif truetype menu font comes from the GNU FreeFont
project ([https://www.gnu.org/software/freefont/](https://www.gnu.org/software/freefont/)) and is GPL'ed.

### Music

    tb_design.ogg aka. "Life by Design", by Dietrich Radel
    tg_genesis.ogg aka. "Genesis (In The Beginning)", by Dietrich Radel
    tb_hrluebke.ogg, by M3 (Marco Göbel <goebel29@web.de>)
    tb_plinkeplanke.ogg, by M3 (Marco Göbel <goebel29@web.de>)
    tb_schizophrenia.ogg, by Attila Boros (Attila Boros <wraith13@gmail.com>)
    tb_sorrow.ogg, by Attila Boros (Attila Boros <wraith13@gmail.com>)

### Images

Mathias Broxvall, Dietrich Radel, Manuel Stoeckl. All GPL'ed


### Sound effects

The sound effects are taken from KDE, from Benoit Rouits and from 
Joshua Harding. They are of course all GPL'ed.

    blackDie.wav         - Benoit Rouits
    ff_death.wav         - Benoit Rouits
    levelComplete.wav    - Benoit Rouits
    start.wav            - Benoit Rouits
    die.wav              - Benoit Rouits
    flag.wav             - KDE
    sandcrash.wav        - Benoit Rouits
    time_warning.wav     - Benoit Rouits
    switch.wav           - Benoit Rouits
    badpill.wav          - Joshua Harding
    godppill.wav         - Joshua Harding
    savepoint.wav        - Joshua Harding
    timeout.wav          - Joshua Harding
    capuchmonk.wav       - Rusty Johnson     http://www.WildlifeLectures.com
    fall_death.wav       - Laurent           http://www.tplm.com
    Kill_death.wav       - Bob Bailey        http://www.a1freesoundeffects.com
    crash.wav            - Justus            http://www.sq7.org/Community/sounds
    roll_sound.wav       - Warren D.Ober     Contributor
    machine_loop.wav     - Warren D.Ober     Contributor
    click.wav            - Warren D.Ober     Contributor
    ball_sinks.wav       - Warren D.Ober     Contributor
    ball_sinks2.wav      - Warren D.Ober     Contributor


Also, for one of the sound effects I have promised to include this
notice:

       **                                     **
       **  The sample of the Capuchin Monkey  **
       **  call is provided courtesy of:      **
       **                                     **
       **        Rusty Johnson                **
       **        The Aylazon Foundation       **
       **        WildlifeLectures.com         **
       **                                     **
